library(dplyr)
library(haven)
library(psych)
library(PerformanceAnalytics)
library(corrplot)
library(Hmisc)
library(lavaan)
library(semTools)
library(mvnTest)
library(mvnormalTest)

###Validity analysis###

CRS_dec <- read_sav("CRS_dec.sav") %>%
  filter(COUNTRY == 3) %>%
  select(starts_with("CRS_"), starts_with("enrich_"), starts_with("p_stress_"), starts_with("lie_"))
attach(CRS_dec)
CRS_dec$agree2 <- CRS_6 + CRS_9r + CRS_11r + CRS_15r
CRS_dec$close2 <- CRS_2 + CRS_17 + CRS_24 + CRS_28r + CRS_30
CRS_dec$exp2 <- CRS_31 + CRS_32 + CRS_33 + CRS_34 + CRS_35
CRS_dec$supp2 <- CRS_3 + CRS_10 + CRS_19 + CRS_25 + CRS_26 + CRS_27
CRS_dec$und2 <- CRS_8 + CRS_12 + CRS_13 + CRS_16 + CRS_21 + CRS_22
CRS_dec$par2 <- CRS_1 + CRS_4 + CRS_7r + CRS_14 + CRS_18 + CRS_23 + CRS_29r
CRS_dec$RW2 <- CRS_7r + CRS_9r +
  CRS_11r + CRS_15r + CRS_28r + CRS_29r + CRS_31 + CRS_32 + 
  CRS_33 + CRS_34 + CRS_35 + CRS_20r + CRS_5r +
  CRS_8 + CRS_12 + CRS_13 + CRS_16 + CRS_21 + CRS_22
CRS_dec$CRS_Full <- CRS_6 + CRS_9r + CRS_11r + CRS_15r + CRS_2 + CRS_17 + CRS_24 + CRS_28r + CRS_30 + CRS_31r + CRS_32r + CRS_33r + CRS_34r + CRS_35r + CRS_3 + CRS_10 + CRS_19 + CRS_25 + CRS_26 + CRS_27 + CRS_8r + CRS_12r + CRS_13r + CRS_16r + CRS_21r + CRS_22r + CRS_1 + CRS_4 + CRS_7r + CRS_14 + CRS_18 + CRS_23 + CRS_29r
CRS_dec$enr2 <- enrich_1 +	enrich_2 +	enrich_3 +	enrich_4 +	enrich_5 +	enrich_6 +	enrich_7 +	enrich_8 +	enrich_9 +	enrich_10 +	enrich_11 +	enrich_12 +	enrich_13 +	enrich_14 +	enrich_15
CRS_dec$pstr2 <- p_stress_1 +	p_stress_2 +	p_stress_3 +	p_stress_4 +	p_stress_5 +	p_stress_6 +	p_stress_7
CRS_dec$lie2 <- lie_1 +	lie_2 +	lie_3 +	lie_4 +	lie_5 +	lie_6 +	lie_7 +	lie_8 +	lie_9 +	lie_10 +	lie_11 +	lie_12
View(CRS_dec)
write.csv(CRS_dec, "CRS_dec.csv", quote = FALSE, row.names = FALSE)
CRS_dec.csv <- read.csv("CRS_dec.csv", header = TRUE) %>%
  select(agree2, close2, exp2, supp2, und2, par2, RW2, CRS_Full, enr2, pstr2, lie2)

rcorr(as.matrix(CRS_dec.csv), type=c("spearman")) #"pearson"

###LEGEND###
# agree2 = Coparenting agreement
# close2 = Coparenting closeness
# exp2 = Exposure to conflict
# supp2 = Coparenting support
# und2 = 	Coparenting undermining	
# par2 = Endorsement partner’s parenting
# RW2 = Reverse worded items
# CRS_Full = Full method of CRS items (without CRS_5 and CRS_20)
# enr2 = the ENRICH Marital Satisfaction (EMS) Scale
# pstr2 = Pearlin’s Parental Distress Scale
# lie2 = Lie Scale of the Eysenck Personality Questionnaire-Revised (EPQ-R)